summaryrefslogtreecommitdiffstats
path: root/juk/tageditor.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/tageditor.h')
-rw-r--r--juk/tageditor.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/juk/tageditor.h b/juk/tageditor.h
index c62df207..8a616f15 100644
--- a/juk/tageditor.h
+++ b/juk/tageditor.h
@@ -34,12 +34,13 @@ typedef TQValueList<PlaylistItem *> PlaylistItemList;
class CollectionObserver;
-class TagEditor : public QWidget
+class TagEditor : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
- TagEditor(TQWidget *parent = 0, const char *name = 0);
+ TagEditor(TQWidget *tqparent = 0, const char *name = 0);
virtual ~TagEditor();
PlaylistItemList items() const { return m_items; }
void setupObservers();
@@ -66,10 +67,10 @@ private:
void save(const PlaylistItemList &list);
void saveChangesPrompt();
/**
* Adds an item to JuK's tagging layout. This handles the creation and
* placement of the "enable" box as well.
*/
- void addItem(const TQString &text, TQWidget *item, TQBoxLayout *layout, const TQString &iconName = TQString::null);
+ void addItem(const TQString &text, TQWidget *item, TQBoxLayout *tqlayout, const TQString &iconName = TQString());
/**
* Adds a widget to m_hideList and returns that widget.
@@ -66,10 +67,10 @@ private:
void saveChangesPrompt();
/**
- * Adds an item to JuK's tagging layout. This handles the creation and
+ * Adds an item to JuK's tagging tqlayout. This handles the creation and
* placement of the "enable" box as well.
*/